# coding: utf-8

"""
    Amber Electric Public API

    Amber is an Australian-based electricity retailer that pass through the real-time wholesale price of energy.  Because of Amber's wholesale power prices, you can save hundreds of dollars a year by automating high power devices like air-conditioners, heat pumps and pool pumps.  This Python library provides an interface to the API, allowing you to react to current and forecast prices, as well as download your historic usage.

    The version of the OpenAPI document: 2.0.0
    Contact: dev@amber.com.au
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from amberelectric.models.renewable_descriptor import RenewableDescriptor  # noqa: E501

class TestRenewableDescriptor(unittest.TestCase):
    """RenewableDescriptor unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testRenewableDescriptor(self):
        """Test RenewableDescriptor"""
        # inst = RenewableDescriptor()

if __name__ == '__main__':
    unittest.main()
